@@ -33,6 +33,11 @@ DO_NOT_SORT = ["Layers"]
 
 BASE_PATH = os.path.dirname(__file__)
 INPUT_FOLDER = os.path.join(BASE_PATH, "input")
+SUCCESS_FILES_NAMES_FOR_TESTING = [
+    os.path.splitext(f)[0]
+    for f in os.listdir(INPUT_FOLDER)
+    if not (f.startswith("error_") or f.startswith("translate_"))
+]
 ERROR_FILES_NAMES_FOR_TESTING = [os.path.splitext(f)[0] for f in os.listdir(INPUT_FOLDER) if f.startswith("error_")]
 OUTPUT_FOLDER = os.path.join(BASE_PATH, "output")
 
@@ -253,238 +258,7 @@ class AbstractTestTranslator(TestCase):
 class TestTranslatorEndToEnd(AbstractTestTranslator):
     @parameterized.expand(
         itertools.product(
-            [
-                "congito_userpool_with_sms_configuration",
-                "cognito_userpool_with_event",
-                "s3_with_condition",
-                "function_with_condition",
-                "basic_function",
-                "basic_function_withimageuri",
-                "basic_application",
-                "application_preparing_state",
-                "application_with_intrinsics",
-                "basic_layer",
-                "cloudwatchevent",
-                "cloudwatchevent_intrinsics",
-                "eventbridgerule",
-                "eventbridgerule_with_dlq",
-                "eventbridgerule_with_retry_policy",
-                "eventbridgerule_schedule_properties",
-                "cloudwatch_logs_with_ref",
-                "cloudwatchlog",
-                "streams",
-                "sqs",
-                "function_with_amq",
-                "function_with_amq_kms",
-                "function_with_mq_virtual_host",
-                "simpletable",
-                "simpletable_with_sse",
-                "resource_with_invalid_type",
-                "implicit_api",
-                "explicit_api",
-                "api_description",
-                "api_endpoint_configuration",
-                "api_endpoint_configuration_with_vpcendpoint",
-                "api_with_auth_all_maximum",
-                "api_with_auth_all_minimum",
-                "api_with_auth_no_default",
-                "api_with_auth_with_default_scopes",
-                "api_with_auth_with_default_scopes_openapi",
-                "api_with_default_aws_iam_auth",
-                "api_with_default_aws_iam_auth_and_no_auth_route",
-                "api_with_method_aws_iam_auth",
-                "api_with_aws_iam_auth_overrides",
-                "api_with_swagger_authorizer_none",
-                "api_with_method_settings",
-                "api_with_binary_media_types",
-                "api_with_binary_media_types_definition_body",
-                "api_with_minimum_compression_size",
-                "api_with_resource_refs",
-                "api_with_cors",
-                "api_with_cors_and_auth_no_preflight_auth",
-                "api_with_cors_and_auth_preflight_auth",
-                "api_with_cors_and_only_methods",
-                "api_with_cors_and_only_headers",
-                "api_with_cors_and_only_origins",
-                "api_with_cors_and_only_maxage",
-                "api_with_cors_and_only_credentials_false",
-                "api_with_cors_no_definitionbody",
-                "api_with_incompatible_stage_name",
-                "api_with_gateway_responses",
-                "api_with_gateway_responses_all",
-                "api_with_gateway_responses_minimal",
-                "api_with_gateway_responses_implicit",
-                "api_with_gateway_responses_string_status_code",
-                "api_with_identity_intrinsic",
-                "api_cache",
-                "api_with_access_log_setting",
-                "api_with_any_method_in_swagger",
-                "api_with_canary_setting",
-                "api_with_xray_tracing",
-                "api_request_model",
-                "api_request_model_with_validator",
-                "api_with_stage_tags",
-                "api_with_mode",
-                "api_with_no_properties",
-                "api_with_disable_api_execute_endpoint",
-                "s3",
-                "s3_create_remove",
-                "s3_existing_lambda_notification_configuration",
-                "s3_existing_other_notification_configuration",
-                "s3_filter",
-                "s3_intrinsics",
-                "s3_multiple_events_same_bucket",
-                "s3_multiple_functions",
-                "s3_with_dependsOn",
-                "sns",
-                "sns_sqs",
-                "sns_existing_sqs",
-                "sns_intrinsics",
-                "sns_outside_sqs",
-                "sns_existing_other_subscription",
-                "sns_topic_outside_template",
-                "alexa_skill",
-                "alexa_skill_with_skill_id",
-                "iot_rule",
-                "kinesis_intrinsics",
-                "layers_with_intrinsics",
-                "layers_all_properties",
-                "layer_deletion_policy_precedence",
-                "function_managed_inline_policy",
-                "unsupported_resources",
-                "intrinsic_functions",
-                "basic_function_with_tags",
-                "depends_on",
-                "function_with_ephemeral_storage",
-                "function_event_conditions",
-                "function_with_dlq",
-                "function_with_kmskeyarn",
-                "function_with_alias",
-                "function_with_alias_intrinsics",
-                "function_with_custom_codedeploy_deployment_preference",
-                "function_with_custom_conditional_codedeploy_deployment_preference",
-                "function_with_disabled_deployment_preference",
-                "function_with_disabled_traffic_hook",
-                "function_with_deployment_preference",
-                "function_with_deployment_preference_condition_with_passthrough",
-                "function_with_deployment_preference_condition_without_passthrough",
-                "function_with_deployment_preference_all_parameters",
-                "function_with_deployment_preference_from_parameters",
-                "function_with_deployment_preference_multiple_combinations",
-                "function_with_deployment_preference_alarms_intrinsic_if",
-                "function_with_deployment_preference_multiple_combinations_conditions_with_passthrough",
-                "function_with_deployment_preference_multiple_combinations_conditions_without_passthrough",
-                "function_with_deployment_preference_passthrough_condition_with_supported_intrinsics",
-                "function_with_alias_and_event_sources",
-                "function_with_resource_refs",
-                "function_with_deployment_and_custom_role",
-                "function_with_deployment_no_service_role_with_passthrough",
-                "function_with_deployment_no_service_role_without_passthrough",
-                "function_with_global_layers",
-                "function_with_layers",
-                "function_with_many_layers",
-                "function_with_null_events",
-                "function_with_permissions_boundary",
-                "function_with_policy_templates",
-                "function_with_sns_event_source_all_parameters",
-                "function_with_conditional_managed_policy",
-                "function_with_conditional_managed_policy_and_ref_no_value",
-                "function_with_conditional_policy_template",
-                "function_with_conditional_policy_template_and_ref_no_value",
-                "function_with_request_parameters",
-                "function_with_signing_profile",
-                "global_handle_path_level_parameter",
-                "globals_for_function",
-                "globals_for_api",
-                "globals_for_simpletable",
-                "all_policy_templates",
-                "simple_table_ref_parameter_intrinsic",
-                "simple_table_with_table_name",
-                "function_concurrency",
-                "simple_table_with_extra_tags",
-                "explicit_api_with_invalid_events_config",
-                "no_implicit_api_with_serverless_rest_api_resource",
-                "implicit_api_deletion_policy_precedence",
-                "implicit_api_with_serverless_rest_api_resource",
-                "implicit_api_with_auth_and_conditions_max",
-                "implicit_api_with_many_conditions",
-                "implicit_and_explicit_api_with_conditions",
-                "inline_precedence",
-                "api_with_cors_and_conditions_no_definitionbody",
-                "api_with_auth_and_conditions_all_max",
-                "api_with_apikey_default_override",
-                "api_with_apikey_required",
-                "api_with_apikey_source",
-                "api_with_path_parameters",
-                "function_with_event_source_mapping",
-                "function_with_event_dest",
-                "function_with_event_dest_basic",
-                "function_with_event_dest_conditional",
-                "api_with_usageplans",
-                "api_with_usageplans_shared_attributes_two",
-                "api_with_usageplans_shared_attributes_three",
-                "api_with_usageplans_intrinsics",
-                "state_machine_with_inline_definition",
-                "state_machine_with_tags",
-                "state_machine_with_inline_definition_intrinsics",
-                "state_machine_with_role",
-                "state_machine_with_inline_policies",
-                "state_machine_with_sam_policy_templates",
-                "state_machine_with_definition_S3_string",
-                "state_machine_with_definition_S3_object",
-                "state_machine_with_definition_substitutions",
-                "state_machine_with_standard_logging",
-                "state_machine_with_express_logging",
-                "state_machine_with_managed_policy",
-                "state_machine_with_condition",
-                "state_machine_with_schedule",
-                "state_machine_with_schedule_dlq_retry_policy",
-                "state_machine_with_cwe",
-                "state_machine_with_eb_retry_policy",
-                "state_machine_with_eb_dlq",
-                "state_machine_with_eb_dlq_generated",
-                "state_machine_with_explicit_api",
-                "state_machine_with_implicit_api",
-                "state_machine_with_implicit_api_globals",
-                "state_machine_with_api_authorizer",
-                "state_machine_with_api_authorizer_maximum",
-                "state_machine_with_api_resource_policy",
-                "state_machine_with_api_auth_default_scopes",
-                "state_machine_with_condition_and_events",
-                "state_machine_with_xray_policies",
-                "state_machine_with_xray_role",
-                "state_machine_with_null_events",
-                "function_with_file_system_config",
-                "state_machine_with_permissions_boundary",
-                "version_deletion_policy_precedence",
-                "api_swagger_integration_with_string_api_id",
-                "api_swagger_integration_with_ref_intrinsic_api_id",
-                "function_with_architectures",
-                "function_with_intrinsic_architecture",
-                "self_managed_kafka_with_intrinsics",
-                "function_with_self_managed_kafka",
-                "function_with_auth_mechanism_for_self_managed_kafka",
-                "function_with_vpc_permission_for_self_managed_kafka",
-                "function_with_event_filtering",
-                "api_with_security_definition_and_components",
-                "api_with_security_definition_and_none_components",
-                "api_with_security_definition_and_no_components",
-                "api_http_paths_with_if_condition",
-                "api_http_paths_with_if_condition_no_value_then_case",
-                "api_http_paths_with_if_condition_no_value_else_case",
-                "api_rest_paths_with_if_condition_swagger",
-                "api_rest_paths_with_if_condition_swagger_no_value_then_case",
-                "api_rest_paths_with_if_condition_swagger_no_value_else_case",
-                "api_rest_paths_with_if_condition_openapi",
-                "api_rest_paths_with_if_condition_openapi_no_value_then_case",
-                "api_rest_paths_with_if_condition_openapi_no_value_else_case",
-                "function_with_function_url_config",
-                "function_with_function_url_config_conditions",
-                "function_with_function_url_config_with_intrinsics",
-                "function_with_function_url_config_with_iam_authorization_type",
-                "function_with_function_url_config_without_cors_config",
-                "function_with_function_url_config_and_autopublishalias",
-            ],
+            SUCCESS_FILES_NAMES_FOR_TESTING,
             [
                 ("aws", "ap-southeast-1"),
                 ("aws-cn", "cn-north-1"),
